@@ -4,35 +4,36 @@ use Text::RewriteRules;
 
 use strict;
 our %letra;
+our %mat;
 
 BEGIN {
   %letra = (
-	    a=>"  ",
-	    b=>" b ",
-	    c=>" c ",
-	    d=>" d ",
-	    e=>"  ",
-	    f=>" efe ",
-	    g=>" gu ",
-	    h=>" ag ",
-	    i=>"  ",
-	    j=>" jta ",
-	    k=>" kapa ",
-	    l=>" le ",
-	    m=>" eme ",
-	    n=>" ene ",
-	    o=>"  ",
-	    p=>" p ",
-	    q=>" qu ",
-	    r=>" rre ",
-	    s=>" sse ",
-	    t=>" t ",
-	    u=>"  ",
-	    v=>" v ",
-	    w=>" dobliu ",
-	    x=>" xis ",
-	    y=>" ipsilon ",
-	    z=>" z ",
+	    a=>"",
+	    b=>"b",
+	    c=>"c",
+	    d=>"d",
+	    e=>"",
+	    f=>"fe",
+	    g=>"gu",
+	    h=>"ag",
+	    i=>"",
+	    j=>"jta",
+	    k=>"kpa",
+	    l=>"le",
+	    m=>"me",
+	    n=>"ne",
+	    o=>"",
+	    p=>"p",
+	    q=>"qu",
+	    r=>"rre",
+	    s=>"sse",
+	    t=>"t",
+	    u=>"",
+	    v=>"v",
+	    w=>"dablew",
+	    x=>"xs",
+	    y=>"psilon",
+	    z=>"z",
 
 	    '~' =>" til ",
 	    ':' =>" dois pontos ",
@@ -45,32 +46,86 @@ BEGIN {
 	    '>' => ' maior ',
 	    '|' => ' barra ',
 	    '#' => ' cardinal ',
+            '%' => ' por cento ',
 	    "\cM" => ' nova pgina ',
 	   );
 
+  %mat = (
+	    '~' =>" til ",
+	    ':' =>" dois pontos ",
+	    '-' =>", menos ",
+	    '_' =>" sublinhado ",
+	    '/' =>" sobre ",
+	    '$' =>" dlar ",
+	    '=' => ', igual ',
+	    '=>' => ', implica ',
+	    '<=>' => ', equivale a ',
+	    '^' => ' elevado a ',
+	    '/\\' => ' ii ',
+	    '\/' => ', ouu ',
+	    '+' => ', mais ',
+	    '*' => ' vezes ',
+	    '<' => ', menor ',
+	    '>' => ', maior ',
+	    '|' => ' barra ',
+	    '!' => ' factorial ',
+            '%' => ' por cento ',
+	    '#' => ' cardinal de ',
+	   );
+
 }
 
-MRULES email
+RULES/m email
 \n==>
 \.==> ponto 
 \@==> arroba 
 :\/\/==> doispontos barra barra 
 :==> doispontos 
 (net)\b==> nte 
-(www)\b==> dabliudabliudabliu 
+(www)\b==> dablidablidabliw 
 (http)\b==> agttp 
 (com)\b==> cme 
-(org)\b==> orgue 
-([a-zA-Z]{1,3}?)\b=e=>join("",map {$letra{lc($_)}} split(//,$1)).", "
+(org)\b==> rg 
+#([a-zA-Z]{1,3}?)\b=e=>join("",map {$letra{lc($_)}} split(//,$1)).", "
+([a-zA-Z]{1,3}?)\b=e=>" ".sigla($1). " "
 (.+?)\b==>$1 
 ENDRULES
 
-RULES nontext
+RULES/m acron
+e(?=[nm])==>
+a==>
+e==>
+i==>
+o==>
+u==>
+ENDRULES
+
+RULES/m sigla
+([a-zA-Z])=e=>$letra{lc($1)} || " $1 "
+ENDRULES
+
+RULES/m math
+\b([a-z])\b\s*2\b==> $letra{$1} ao quadrado 
+\b([a-z])\b\s*3\b==> $letra{$1} ao cubo 
+\b([a-z])\b\s*(\d)\b==> $letra{$1}  $2 
+([^\w\s]+)==> $mat{$1} !! defined $mat{$1}
+\b([a-z])\b==> $letra{$1} 
+\bcos\b==>cosseno de
+\bs[ie]n\b==>seno de
+\blog\b==>logaritmo de 
+\bexp\b==>exponencial de 
+\bsqrt\b==>raz de 
+\bmod\b==>mdulo de 
+ENDRULES
+
+RULES/m nontext
 (\w)-(\w)==>$1 $2
-([\-*=<>#\|\~_/\cM:])=e=>$letra{$1}
+([\-*=<>#\|\~_/\cM:%])=e=>" $letra{$1} "
 ENDRULES
 
 RULES number
+(\d+)\s*\%==>$1 por cento
+(\d+)\.(\d+)==>$1 ponto $2
 (\d+)(000000)\b==>$1 milho!!            $1 == 1
 (\d+)(000000)\b==>$1 milhes
 (\d+)(000)(\d{3})==>$1 milho e $3!!     $1 == 1
